==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property outputSdt
 * @property repInterval
 * @property serviceName
 * @property serviceProviderName
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs(
    public val outputSdt: Output<String>? = null,
    public val repInterval: Output<Int>? = null,
    public val serviceName: Output<String>? = null,
    public val serviceProviderName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs> {
    override fun toJava():
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.builder()
            .outputSdt(outputSdt?.applyValue({ args0 -> args0 }))
            .repInterval(repInterval?.applyValue({ args0 -> args0 }))
            .serviceName(serviceName?.applyValue({ args0 -> args0 }))
            .serviceProviderName(serviceProviderName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgsBuilder
internal constructor() {
    private var outputSdt: Output<String>? = null

    private var repInterval: Output<Int>? = null

    private var serviceName: Output<String>? = null

    private var serviceProviderName: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("qdhcbdqfhtuekiph")
    public suspend fun outputSdt(`value`: Output<String>) {
        this.outputSdt = value
    }

    /**
     * @param value
     */
    @JvmName("nvgslomtxbkjyphp")
    public suspend fun repInterval(`value`: Output<Int>) {
        this.repInterval = value
    }

    /**
     * @param value
     */
    @JvmName("repymbpjcxsvsnpg")
    public suspend fun serviceName(`value`: Output<String>) {
        this.serviceName = value
    }

    /**
     * @param value
     */
    @JvmName("mdvxubdssihxcsmu")
    public suspend fun serviceProviderName(`value`: Output<String>) {
        this.serviceProviderName = value
    }

    /**
     * @param value
     */
    @JvmName("rmiyxjflehcweqci")
    public suspend fun outputSdt(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.outputSdt = mapped
    }

    /**
     * @param value
     */
    @JvmName("xdpvmjblvdsctuyc")
    public suspend fun repInterval(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repInterval = mapped
    }

    /**
     * @param value
     */
    @JvmName("cpyrpinvbgkpxiqa")
    public suspend fun serviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceName = mapped
    }

    /**
     * @param value
     */
    @JvmName("yjwlguvlaxtxtspy")
    public suspend fun serviceProviderName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderName = mapped
    }

    internal fun build():
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs =
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs(
            outputSdt = outputSdt,
            repInterval = repInterval,
            serviceName = serviceName,
            serviceProviderName = serviceProviderName,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property outputSdt
 * @property repInterval
 * @property serviceName
 * @property serviceProviderName
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs(
    public val outputSdt: Output<String>? = null,
    public val repInterval: Output<Int>? = null,
    public val serviceName: Output<String>? = null,
    public val serviceProviderName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs> {
    override fun toJava(): com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.builder()
            .outputSdt(outputSdt?.applyValue({ args0 -> args0 }))
            .repInterval(repInterval?.applyValue({ args0 -> args0 }))
            .serviceName(serviceName?.applyValue({ args0 -> args0 }))
            .serviceProviderName(serviceProviderName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgsBuilder
internal constructor() {
    private var outputSdt: Output<String>? = null

    private var repInterval: Output<Int>? = null

    private var serviceName: Output<String>? = null

    private var serviceProviderName: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("jcduhwmnkohsumur")
    public suspend fun outputSdt(`value`: Output<String>) {
        this.outputSdt = value
    }

    /**
     * @param value
     */
    @JvmName("gcooswyghnlxfytr")
    public suspend fun repInterval(`value`: Output<Int>) {
        this.repInterval = value
    }

    /**
     * @param value
     */
    @JvmName("qoiodvspwnbjrtht")
    public suspend fun serviceName(`value`: Output<String>) {
        this.serviceName = value
    }

    /**
     * @param value
     */
    @JvmName("askiymutwbucrvje")
    public suspend fun serviceProviderName(`value`: Output<String>) {
        this.serviceProviderName = value
    }

    /**
     * @param value
     */
    @JvmName("rtxntcjkeeasgnfe")
    public suspend fun outputSdt(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.outputSdt = mapped
    }

    /**
     * @param value
     */
    @JvmName("pedpohanogwxnmjb")
    public suspend fun repInterval(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repInterval = mapped
    }

    /**
     * @param value
     */
    @JvmName("dospxbkwyaukhlhb")
    public suspend fun serviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceName = mapped
    }

    /**
     * @param value
     */
    @JvmName("ginepceiverfrwwu")
    public suspend fun serviceProviderName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderName = mapped
    }

    internal fun build(): ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs =
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsArchiveOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs(
            outputSdt = outputSdt,
            repInterval = repInterval,
            serviceName = serviceName,
            serviceProviderName = serviceProviderName,
        )
}
